@@ -2,9 +2,9 @@
 // DALY.cpp
 // C++ interaction file for R DALY Package
 //
-// <author>     Brecht.Devleesschauwer@UGent.be
-// <version>    1.3.1
-// <date>       10/07/2014
+// <author>     brechtdv@gmail.com
+// <version>    1.5.0
+// <date>       2016/11/25
 //
 
 #include <iostream>
@@ -162,7 +162,7 @@ extern "C" {
 
     double getLxp(double age, int sex, double lxpList[])
     {
-        int point = round(age*10) + sex*951;
+        int point = fround(age*10, 0) + sex*951;
         double value = lxpList[point];
         return(value);
     }
